interface ApiResult<TData = any, TError = any> {
    loading: boolean;
    data: TData | null | undefined;
    error: TError | null | undefined;
}
export class Cache {
    data: Record<string, ApiResult>;
    subscriptions: Record<string, (() => void)[]>;
    get: <TData, TError>(key: string) => ApiResult<TData, TError>;
    set: <TData, TError>(key: string, value: ApiResult<TData, TError>) => void;
    subscribe: (key: string, callback: () => void) => void;
    unsubscribe: (key: string, callback: () => void) => void;
}
export type ApiVariables<T extends Partial<Record<'body' | 'query' | 'body', any>> = {}> = T;
interface ApiConfig<APIs> {
    fetcher: (api: APIs[keyof APIs], variables: ApiVariables) => Promise<unknown>;
    refetchOnFocus?: boolean;
    useFocused?: () => boolean;
}
type ApiProviderProps<T> = React.PropsWithChildren<{
    cache?: Cache;
    config: ApiConfig<T>;
}>;
interface OnCompletedParams<T, TData extends Record<keyof T, any>, TError extends Record<keyof T, any>, TVariables extends Record<keyof T, any>, K extends keyof T> {
    data: TData[K] | null;
    error: TError[K] | null;
    revalidate: <X extends keyof T, TApiData extends TData[X], TApiError extends TError[X], TApiVariables extends TVariables[X]>(key: X, variables: TApiVariables) => Promise<{
        data: TApiData | null;
        error: TApiError | null;
    }>;
    mutate: <X extends keyof T, TApiData extends TData[X], TApiVariables extends TVariables[X]>(key: X, variables: TApiVariables, callback: (prevData: TApiData) => TApiData) => TApiData;
}
export interface UseLazyApiOptions<T, TData extends Record<keyof T, any>, TError extends Record<keyof T, any>, TVariables extends Record<keyof T, any>, K extends keyof T> {
    cached?: boolean;
    refetchOnFocus?: boolean;
    variables?: TVariables;
    onFetch?: () => Promise<any>;
    onCompleted?: (params: OnCompletedParams<T, TData, TError, TVariables, K>) => any;
}
export interface UseApiOptions<T, TData extends Record<keyof T, any>, TError extends Record<keyof T, any>, TVariables extends Record<keyof T, any>, K extends keyof T> extends UseLazyApiOptions<T, TData, TError, TVariables, K> {
    skip?: boolean;
    force?: boolean;
}
export function createAPIs<T, TData extends Record<keyof T, any> = any, TError extends Record<keyof T, any> = any, TVariables extends Record<keyof T, any> = any>(apis: T): {
    Provider: ({ config, children, cache, }: ApiProviderProps<T>) => JSX.Element;
    useLazyApi: <K extends keyof T, TApiData extends TData[K], TApiError extends TError[K], TApiVariables extends TVariables[K]>(key: K, defaultOpts?: UseLazyApiOptions<T, TData, TError, TVariables, K>) => readonly [(opts?: Pick<UseLazyApiOptions<T, TData, TError, TVariables, K>, "variables">) => Promise<{
        data: TApiData | null;
        error: TApiError | null;
    }>, {
        readonly refetch: () => Promise<{
            data: TApiData | null;
            error: TApiError | null;
        }>;
        readonly loading: boolean;
        readonly data: TApiData | null | undefined;
        readonly error: TApiError | null | undefined;
    }];
    useMutationApi: <K_1 extends keyof T, TApiData_1 extends TData[K_1], TApiError_1 extends TError[K_1], TApiVariables_1 extends TVariables[K_1]>(key: K_1, opts?: UseLazyApiOptions<T, TData, TError, TVariables, K_1>) => readonly [(opts?: Pick<UseLazyApiOptions<T, TData, TError, TVariables, K_1>, "variables">) => Promise<{
        data: TApiData_1 | null;
        error: TApiError_1 | null;
    }>, {
        readonly refetch: () => Promise<{
            data: TApiData_1 | null;
            error: TApiError_1 | null;
        }>;
        readonly loading: boolean;
        readonly data: TApiData_1 | null | undefined;
        readonly error: TApiError_1 | null | undefined;
    }];
    useApi: <K_2 extends keyof T, TApiData_2 extends TData[K_2], TApiError_2 extends TError[K_2], TApiVariables_2 extends TVariables[K_2]>(key: K_2, opts?: UseApiOptions<T, TData, TError, TVariables, K_2>) => {
        loading: boolean;
        called: boolean;
        refetch: () => Promise<{
            data: TApiData_2 | null;
            error: TApiError_2 | null;
        }>;
        data: TApiData_2 | null | undefined;
        error: TApiError_2 | null | undefined;
    };
    useRevalidate: () => <K_3 extends keyof T, TApiData_3 extends TData[K_3], TApiError_3 extends TError[K_3], TApiVariables_3 extends TVariables[K_3]>(key: K_3, variables: TApiVariables_3) => Promise<{
        data: TApiData_3 | null;
        error: TApiError_3 | null;
    }>;
};

//# sourceMappingURL=types.d.ts.map
